# tf_coil_coordinator

This package runs a function to calculate the coordinates of the vertexes for
a TF Coil profile on a 2D XZ planar projection

- uses PyPi to deploy a pip install
- uses branches on git to control software version and development
- uses github actions to upload PyPi

To install:
```bash
pip install tf_coil_coordinator
```

